@@ -5,11 +5,9 @@
 ##' This function will discard coordinates that fall within a certain distance
 ##' from other points.
 ##' 
-##' @param xy longitude and latitude in decimal degrees, either as class
-##' matrix, SpatialPoints or SpatialPointsDataFrame.
-##' @param dist minimum allowed distance
-##' @param mapUnits if \code{TRUE}, distance is interpreted in map units,
-##' distance in kilometers if \code{FALSE}
+##' @param xy longitude and latitude in decimal degrees, either as a matrix,
+##' dataframe, or spatial points object.
+##' @param dist minimum allowed distance in km
 ##' @param returnIndex if \code{TRUE}, will return indices of points that would
 ##' be dropped, if \code{FALSE}, returns the points that satisfy the distance
 ##' filter.
@@ -26,31 +24,47 @@
 ##' 
 ##' subset <- crotalus[1:100,]
 ##' tooClose <- filterByProximity(xy= subset[ ,c('decimallongitude','decimallatitude')], 
-##' 	dist=20, mapUnits = FALSE, returnIndex = TRUE)
+##' 	dist=20, returnIndex = TRUE)
 ##' 
 ##' plot(subset[ ,c('decimallongitude','decimallatitude')], pch=1, col='blue', cex=1.5)
 ##' points(subset[tooClose, c('decimallongitude','decimallatitude')], pch=20, col='red')
 ##' 
+##'
+##' # testing different input options
+##' samp <- sample(1:nrow(crotalus), 100)
+##' xy <- crotalus[samp, c('decimallongitude', 'decimallatitude')]
+##' sfpts <- sf::st_as_sf(xy, coords = c('decimallongitude', 'decimallatitude'), crs = 4326)
+##' sfptsEA <- sf::st_transform(sfpts, crs = '+proj=eqearth')
+##' spPts <- as(sfpts, 'Spatial')
+##' filterByProximity(xy, dist=20, returnIndex = TRUE)
+##' filterByProximity(sfpts, dist=20, returnIndex = TRUE)
+##' filterByProximity(sfptsEA, dist=20, returnIndex = TRUE)
+##' filterByProximity(spPts, dist=20, returnIndex = TRUE)
+##'
+
 ##' @export
 
-filterByProximity <- function(xy, dist, mapUnits = FALSE, returnIndex = FALSE) {
-
-	#xy can be either a SpatialPoints or SPDF object, or a matrix
-	#dist is in km if mapUnits=F, in mapUnits otherwise
-	#returnIndex = TRUE will return indices of points that would be dropped
-	if (inherits(xy, 'data.frame')) {
-		xy <- as.matrix(xy)
+filterByProximity <- function(xy, dist, returnIndex = FALSE) {
+	
+	# xy can be either a spatial object, or a matrix
+	# returnIndex = TRUE will return indices of points that would be dropped
+	
+	if (inherits(xy, c('SpatialPoints', 'SpatialPointsDataFrame'))) {
+		xy <- sf::st_as_sf(xy)
 	}
-	if (!mapUnits) {
-		d <- spDists(xy,longlat = TRUE)
-	}
-	if (mapUnits) {
-		if (is.matrix(xy)) {
-			d <- as.matrix(dist(xy, method = 'euclidian'))
-		} else {
-			d <- spDists(xy, longlat = FALSE)
+	
+	if (!any(inherits(xy, c('sf', 'sfc')))) {
+		if (ncol(xy) != 2) {
+			stop('xy must be a spatial points object or a 2-column table.')
 		}
-	}
+		
+		xy <- sf::st_as_sf(as.data.frame(xy), coords = 1:2, crs = 4326)
+	} 
+	
+	d <- sf::st_distance(xy, xy) # in meters
+	d <- units::drop_units(d)
+	d <- d / 1000 # in km
+	
 	diag(d) <- NA
 	close <- d <= dist
 	diag(close) <- NA
@@ -63,7 +77,7 @@ filterByProximity <- function(xy, dist, mapUnits = FALSE, returnIndex = FALSE) {
 				closePts <- closePts[-union(which(closePts[,1] == closePts[1,1]), which(closePts[,2] == closePts[1,1])),]
 			}
 		}
-		discard <- discard[complete.cases(discard),]
+		discard <- discard[stats::complete.cases(discard),]
 		if (inherits(discard, 'matrix')) {
 			if (returnIndex) {
 				return(discard[,1])
